@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class ChecksumType
-  {
-    NOT_SET,
-    COMPOSITE,
-    FULL_OBJECT
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class ChecksumType { NOT_SET, COMPOSITE, FULL_OBJECT };
 
-namespace ChecksumTypeMapper
-{
+namespace ChecksumTypeMapper {
 AWS_S3CRT_API ChecksumType GetChecksumTypeForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForChecksumType(ChecksumType value);
-} // namespace ChecksumTypeMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace ChecksumTypeMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
