@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3tables/S3Tables_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3tables/S3Tables_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Tables
-{
-namespace Model
-{
-  enum class OpenTableFormat
-  {
-    NOT_SET,
-    ICEBERG
-  };
+namespace Aws {
+namespace S3Tables {
+namespace Model {
+enum class OpenTableFormat { NOT_SET, ICEBERG };
 
-namespace OpenTableFormatMapper
-{
+namespace OpenTableFormatMapper {
 AWS_S3TABLES_API OpenTableFormat GetOpenTableFormatForName(const Aws::String& name);
 
 AWS_S3TABLES_API Aws::String GetNameForOpenTableFormat(OpenTableFormat value);
-} // namespace OpenTableFormatMapper
-} // namespace Model
-} // namespace S3Tables
-} // namespace Aws
+}  // namespace OpenTableFormatMapper
+}  // namespace Model
+}  // namespace S3Tables
+}  // namespace Aws
